@@ -114,8 +114,11 @@ class Confluence(AtlassianRestAPI):
         :param expand: OPTIONAL: expand e.g. history
         :return:
         """
-        url = 'rest/api/content/{page_id}?expand={expand}'.format(page_id=page_id, expand=expand)
-        return self.get(url)
+        params = {}
+        if expand:
+            params = {expand: expand}
+        url = 'rest/api/content/{page_id}'.format(page_id=page_id)
+        return self.get(url, params=params)
 
     def get_page_labels(self, page_id, prefix=None, start=None, limit=None):
         """
@@ -831,6 +834,32 @@ class Confluence(AtlassianRestAPI):
             response = self.get('rest/supportHealthCheck/1.0/check/')
         return response
 
+    def upload_plugin(self, plugin_path):
+        """
+        Provide plugin path for upload into Jira e.g. useful for auto deploy
+        :param plugin_path:
+        :return:
+        """
+        files = {
+            'plugin': open(plugin_path, 'rb')
+        }
+        headers = {
+            'X-Atlassian-Token': 'nocheck'
+        }
+        upm_token = self.request(method='GET', path='rest/plugins/1.0/', headers=headers, trailing=True).headers[
+            'upm-token']
+        url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
+        return self.post(url, files=files, headers=headers)
+
+    def delete_plugin(self, plugin_key):
+        """
+        Delete plugin
+        :param plugin_key:
+        :return:
+        """
+        url = 'rest/plugins/1.0/{}-key'.format(plugin_key)
+        return self.delete(url)
+
     def get_pdf_download_url_for_confluence_cloud(self, url):
         """
         Confluence cloud does not return the PDF document when the PDF
